/****************************************************************************
**
** Copyright (C) 2022 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Outrun demo.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

import QtQml
import QtOutrun.Mqtt as OM


OM.MqttClient {
    id: root

    hostname: Qt.platform.os === "android" ? "127.0.0.1" : "test.mosquitto.org"

    property var mqttIviSubscription: null
    property var mqttSubscription: null

    required property Screen01 mainScreen
    required property SimuData simulation

    onMessageStringReceived: (message, topic)=> {
        console.log(topic, message)
        switch(topic) {
        case "outrun/ivi/info/speed":
            mainScreen.globalDrivespeed = message;
            break;
        case "outrun/ivi/info/battery":
            mainScreen.globalBattery = message;
            break;
        case "outrun/ivi/info/headlights":
            mainScreen.showHeadLights = (message === "true") ? true : false;
            break;
        case "outrun/ivi/info/mediaplayer/albumart":
            mainScreen.albumArtSource = message;
            break;
        case "outrun/ivi/info/mediaplayer/artist":
            mainScreen.albumArtistText = message;
            break;
        case "outrun/ivi/info/mediaplayer/song":
            mainScreen.albumSongText = message;
            break;
        case "outrun/ivi/info/mediaplayer/playing":
            mainScreen.albumPlaying = (message === "true") ? true : false;
            break;
        case "outrun/ivi/info/temparature":
            mainScreen.currentTemperature = message;
            break;
        case "outrun/ivi/info/weather":
            mainScreen.currentWeather = message;
            break;
        case "outrun/ivi/info/phone/bars":
            mainScreen.networkQuality = message;
            break;
        case "outrun/ivi/info/time":
            mainScreen.currentTime = message;
            break;
        case "outrun/ivi/info/driver":
            mainScreen.driverName = message;
            break;
        case "outrun/ivi/info/range":
            mainScreen.globalMaxdistance = message;
            break;
        // Re-publish these to IVI to keep the states in sync (until No Local is available: QTBUG-100862)
        case "outrun/ivi/environment/night":
            mainScreen.globalNightMode = (message === "true") ? true : false;
            mqttClient.publish("outrun/environment/night", mainScreen.globalNightMode);
            break;
        case "outrun/ivi/environment/city":
            mainScreen.globalCitymode = (message === "true") ? true : false;
            mqttClient.publish("outrun/environment/city", mainScreen.globalCitymode);
            break;
        // Handle these in order to keep them in sync after restart
        case "outrun/generic/simulation":
            simulation.running = (message === "true") ? true : false;
            break;
        case "outrun/generic/debugview":
            mainScreen.debugViewEnabled = (message === "true") ? true : false;
            break;
        }
    }

    onErrorChanged: {
        console.log("MQTT Error: " + error);
    }

    onConnected: {
        console.log("MQTT Connected");
        root.mqttIviSubscription = subscribe("outrun/ivi/#");
        root.mqttSubscription = subscribe("outrun/generic/#");
    }

    Component.onCompleted: {
        connectToHost();
    }
}
