/****************************************************************************
**
** Copyright (C) 2022 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Outrun demo.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef RECEIVER_H
#define RECEIVER_H

#include <QtCore/qobject.h>
#include <QtCore/qdatastream.h>
#include <QtNetwork/qtcpserver.h>

class Receiver : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QString ipAddress READ ipAddress NOTIFY ipAddressChanged)
    Q_PROPERTY(QStringList commands READ commands NOTIFY commandsReceived)
    Q_PROPERTY(QString testScript READ testScript NOTIFY testScriptReceived)

public:
    QString ipAddress() { return m_hostAddress.toString(); }
    QStringList commands() { return m_commands; }
    QByteArray testScript() { return m_testScript; }

    Q_INVOKABLE QString startServer();
    Q_INVOKABLE void disconnectRemote();

    QHostAddress hostAddress() const { return m_hostAddress; }
    bool isConnected() const { return m_connection; }

Q_SIGNALS:
    void ipAddressChanged();
    void testScriptReceived();
    void commandsReceived();
    void remoteConnected();
    void remoteDisconnected();

private Q_SLOTS:
    void acceptRemoteConnection();
    void acceptRemoteDisconnection();
    void readPayload();

private:
    QTcpServer *m_tcpServer = nullptr;
    QTcpSocket *m_connection = nullptr;
    QHostAddress m_hostAddress;
    QDataStream m_incoming;
    QByteArray m_testScript;
    QStringList m_commands;
    int m_serverPort = 36000;
};

#endif // RECEIVER_H
